@@ -76,8 +76,10 @@ For api key:
   "Default Anthropic model ID.
 
 Must be one of the model ID's displayed under \"Available models\"
-when starting a new shell."
-  :type '(choice (const nil) string)
+when starting a new shell.
+
+Can be set to either a string or a function that returns a string."
+  :type '(choice (const nil) string function)
   :group 'agent-shell)
 
 (defcustom agent-shell-anthropic-default-session-mode-id
@@ -127,7 +129,9 @@ Returns an agent configuration alist using `agent-shell-make-agent-config'."
    :welcome-function #'agent-shell-anthropic--claude-code-welcome-message
    :client-maker (lambda (buffer)
                    (agent-shell-anthropic-make-claude-client :buffer buffer))
-   :default-model-id (lambda () agent-shell-anthropic-default-model-id)
+   :default-model-id (lambda () (if (functionp agent-shell-anthropic-default-model-id)
+                                    (funcall agent-shell-anthropic-default-model-id)
+                                  agent-shell-anthropic-default-model-id))
    :default-session-mode-id (lambda () agent-shell-anthropic-default-session-mode-id)
    :install-instructions "See https://github.com/zed-industries/claude-agent-acp for installation."))
 
